@@ -25,13 +25,15 @@
 
 namespace PY {
 
+class Config;
+
 #define MAX_PINYIN_LEN 64
 
 class SpecialPhraseTable;
 
 class PinyinEditor : public PhoneticEditor {
 public:
-    PinyinEditor (PinyinProperties & props, Config & config = PinyinConfig::instance ());
+    PinyinEditor (PinyinProperties & props, Config & config);
 
 protected:
     gboolean processPinyin (guint keyval, guint keycode, guint modifiers);
@@ -46,8 +48,8 @@ protected:
     void updatePreeditText (void);
 
     virtual gboolean processKeyEvent (guint keyval, guint keycode, guint modifiers);
-    virtual void updateAuxiliaryTextBefore (String &buffer) {};
-    virtual void updateAuxiliaryTextAfter  (String &buffer) {};
+    virtual void updateAuxiliaryTextBefore (String &buffer) { };
+    virtual void updateAuxiliaryTextAfter  (String &buffer) { };
 };
 
 };
