@@ -31,30 +31,17 @@ public:
     PinyinEngine (IBusEngine *engine);
     ~PinyinEngine (void);
 
+    // virtual functions
     gboolean processKeyEvent (guint keyval, guint keycode, guint modifiers);
     void focusIn (void);
-    void focusOut (void) {
-        reset ();
-    }
-
-    void reset (void) {
-        m_prev_pressed_key = IBUS_VoidSymbol;
-        m_input_mode = MODE_INIT;
-        for (gint i = 0; i < MODE_LAST; i++) {
-            m_editors[i]->reset ();
-        }
-        m_fallback_editor->reset ();
-    }
-
-    void enable (void) {
-        m_props.reset ();
-    }
-    void disable (void) {}
+    void focusOut (void);
+    void reset (void);
+    void enable (void);
+    void disable (void);
     void pageUp (void);
     void pageDown (void);
     void cursorUp (void);
     void cursorDown (void);
-
     gboolean propertyActivate (const gchar *prop_name, guint prop_state);
     void candidateClicked (guint index, guint button, guint state);
 
